{% extends "djinn_contenttypes/base_edit.html" %}
{% load i18n bootstrap %}

{% block body_class %}ct {{ view.ct_name }} add edit{% endblock %}

{% block header %}
<header>
  <h1>
    {% with ct_label=view.ct_label %}
    {% blocktrans %}Add {{ ct_label }}{% endblocktrans %}
    {% endwith %}
  </h1>
</header>
{% endblock %}


{% block formcontrols %}
<div class="btn-group form-actions">

  <button class="btn btn-primary save-action" type="submit" 
          value="save" name="action">
    {% trans "Save" %}
  </button>
    <button class="btn cancel-action" type="submit" 
          value="cancel" name="action">
    {% trans "Cancel" %}
  </button>
</div>
{% endblock %}
