{% load i18n djinn_contenttypes_tags djinn_workflow_tags %}

<div class="publabels">

  {% if object|state == "private" %}
  <span class="state label label-danger">{% trans "hidden" %}</span>
  {% endif %}

  {% if object.is_scheduled %}
  {% if not object.is_published %}
  <span class="publishing label label-warning"
        data-toggle="tooltip"
        title="{% scheduled_line object %}"
        >
    {% trans "scheduled" %}
  </span>
  {% else %}
  <span class="publishing label label-info"
        data-toggle="tooltip"
        title="{% scheduled_line object %}"
        >
    {% trans "published" %}
  </span>
  {% endif %}
  {% endif %}
</div>
