{% load i18n djinn_contenttypes_tags %}

{% if object.is_scheduled %}
<span class="publine">
  {% if not object.is_published %}
  {% trans "scheduled" %}.
  {% else %}
  {% trans "published" %}.
  {% endif %}
  {% scheduled_line object %}
</span>
{% endif %}
