{% load i18n djinn_contenttypes djinn_workflow_tags %}

{% if obj.is_deleted %}
<del title="{% blocktrans with object_name=obj.ct_label %}{{ object_name }} is removed{% endblocktrans %}">{{ obj.title|abbreviate:truncate }}</del>
{% elif obj|state == "private" %}
  {% if show_link %}
  <a href="{{ title_url }}" class="{{ cssclass }}">
    {{ obj.title|abbreviate:truncate }}
  </a>
  {% else %}
    <del title="{% blocktrans with object_name=obj.ct_label %}{{ object_name }} is not available{% endblocktrans %}">{{ obj.title|abbreviate:truncate }}</del>
  {% endif %}
{% elif not obj.is_published %}
  {% if show_link %}
  <a href="{{ title_url }}" class="{{ cssclass }}">
    {{ obj.title|abbreviate:truncate }}
  </a>
  {% else %}
  <del title="{% blocktrans with object_name=obj.ct_label %}{{ object_name }} is not available{% endblocktrans %}">{{ obj.title|abbreviate:truncate }}</del>
  {% endif %}
{% else %}
<a href="{{ title_url }}" class="{{ cssclass }}">
  {{ obj.title|abbreviate:truncate }}
</a>
{% endif %}
